<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:variable name="font">
<xsl:choose>
<xsl:when test="//Manual[@lang='ru']">Cyrillic</xsl:when>
<xsl:otherwise>Helvetica</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:attribute-set name="manual-title-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">24.0pt</xsl:attribute>
  <xsl:attribute name="line-height">24pt</xsl:attribute>
  <xsl:attribute name="space-after.optimum">25pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="padding-top">3pt</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="chapter-title-number">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">24.0pt</xsl:attribute>
  <xsl:attribute name="line-height">24pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="padding-top">3pt</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="chapter-title-text">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">24.0pt</xsl:attribute>
  <xsl:attribute name="line-height">24pt</xsl:attribute>  
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="padding-top">3pt</xsl:attribute>
  <xsl:attribute name="text-indent">3cm</xsl:attribute>
  <xsl:attribute name="keep-with-next">always</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="table-title-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">10.0pt</xsl:attribute>
  <xsl:attribute name="font-weight">bold</xsl:attribute>
  <xsl:attribute name="line-height">15pt</xsl:attribute>
  <xsl:attribute name="background-color">grey</xsl:attribute>
  <xsl:attribute name="margin-left">25pt</xsl:attribute>
  <xsl:attribute name="space-after">3pt</xsl:attribute>
  <xsl:attribute name="space-before.optimum">10pt</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="section-title-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">12.0pt</xsl:attribute>
  <xsl:attribute name="padding-top">3pt</xsl:attribute>
  <xsl:attribute name="font-weight">bold</xsl:attribute>
  <xsl:attribute name="text-align">left</xsl:attribute>
  <xsl:attribute name="space-before.optimum">25pt</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="subsection-title-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">10.0pt</xsl:attribute>
  <xsl:attribute name="font-weight">bold</xsl:attribute>
  <xsl:attribute name="text-align">left</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="codeline-in-table-style">
  <xsl:attribute name="font-family">Courier</xsl:attribute>
  <xsl:attribute name="font-size">8pt</xsl:attribute>
  <xsl:attribute name="space-before.optimum">3pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
</xsl:attribute-set>





<!-- display title in different formats -->
<xsl:template match="Title">
<xsl:choose>
<!-- manual title -->
<xsl:when test="parent::Manual"><fo:block xsl:use-attribute-sets="manual-title-style"><xsl:apply-templates/></fo:block></xsl:when>
<!-- chapter title -->
<xsl:when test="parent::Chapter"><fo:block xsl:use-attribute-sets="chapter-title-number" id="Chapter_{../@id}"><xsl:if test="not(starts-with(@id, 'appendix')) and not(starts-with(@id, 'biblio'))"><xsl:number count="Chapter" format="1"/></xsl:if></fo:block>
<fo:block xsl:use-attribute-sets="chapter-title-text"><xsl:apply-templates/></fo:block></xsl:when>
<xsl:when test="parent::Licence"><fo:block xsl:use-attribute-sets="chapter-title-number" id="{../@id}"/>
<fo:block xsl:use-attribute-sets="chapter-title-text"><xsl:apply-templates/></fo:block></xsl:when>
<!-- sections' title, with section number -->
<!--<xsl:when test="parent::Section and not(../Manual)"><fo:block xsl:use-attribute-sets="section-title-style" id="Section_{../@id}"><xsl:if test="not(starts-with(../../../@id, 'appendix'))"><xsl:number level="multiple" count="Chapter|Chapter/Content/Section" format="1.1"/>&#160;&#160;</xsl:if><xsl:apply-templates select="Text"/></fo:block></xsl:when>-->
<xsl:when test="parent::Section"><fo:block xsl:use-attribute-sets="section-title-style" id="Section_{../@id}"><xsl:if test="not(starts-with(../../../@id, 'appendix')) and not(../Manual)"><xsl:number level="multiple" count="Chapter|Chapter/Content/Section" format="1.1"/>&#160;&#160;</xsl:if><xsl:apply-templates select="Text"/></fo:block></xsl:when>
<!-- tables(not hidden) title, in grey background and with unique number -->
<xsl:when test="parent::Table"><fo:block id="Table_{../@id}" xsl:use-attribute-sets="table-title-style">Table&#160;<xsl:number level="any" count="Table[not(@class='hidden')]"/>&#160;&#160;<xsl:apply-templates select="Text"/><xsl:value-of select="SubTitle"/></fo:block></xsl:when>
<!-- title of subsections -->
<xsl:when test="parent::Subsection"><fo:block xsl:use-attribute-sets="subsection-title-style" id="{../@id}" space-before.optimum="25pt"><xsl:apply-templates select="Text"/></fo:block></xsl:when>
<!-- title of parts -->
<xsl:when test="parent::Part"><fo:block xsl:use-attribute-sets="subsection-title-style" id="{../@id}" space-before.optimum="15pt"><xsl:apply-templates select="Text"/></fo:block></xsl:when>
</xsl:choose>
</xsl:template>


<xsl:template match="Title" mode="Figure">
<xsl:param name="no"/>
<fo:block id="Figure_{../@id}" xsl:use-attribute-sets="table-title-style">Figure&#160;<xsl:value-of select="$no"/><xsl:if test="SubTitle"><xsl:value-of select="SubTitle"/></xsl:if>&#160;<xsl:apply-templates select="Text"/></fo:block>
</xsl:template>


<!-- text paragraph with various formats -->
<xsl:attribute-set name="indented-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">11.0pt</xsl:attribute>
  <xsl:attribute name="space-before.optimum">15pt</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
  <xsl:attribute name="margin-left">35pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="normal-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">11.0pt</xsl:attribute>
  <xsl:attribute name="color">black</xsl:attribute>
  <xsl:attribute name="space-before.optimum">15pt</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
  <xsl:attribute name="margin-left">25pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="normal-table-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">9.0pt</xsl:attribute>
  <xsl:attribute name="color">black</xsl:attribute>  
  <xsl:attribute name="text-align">left</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Text">
<xsl:choose>
<!-- these text display directly -->
<xsl:when test="parent::Title|parent::Author|parent::Affiliation|parent::Version|parent::Date|parent::Bullet|parent::Footnote"><xsl:apply-templates/></xsl:when>
<!-- text in table cells display with 11pt font size -->
<xsl:when test="parent::th"><fo:block xsl:use-attribute-sets="normal-table-text-style"><xsl:apply-templates select="node()"/></fo:block></xsl:when>
<!-- indented text -->
<xsl:when test="parent::Indented"><fo:block xsl:use-attribute-sets="indented-text-style"><xsl:apply-templates/></fo:block></xsl:when>
<!-- normal text paragraphs -->
<xsl:otherwise><fo:block xsl:use-attribute-sets="normal-text-style"><xsl:apply-templates/></fo:block></xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:attribute-set name="version-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">12.0pt</xsl:attribute>
  <xsl:attribute name="color">black</xsl:attribute>
  <xsl:attribute name="font-weight">bold</xsl:attribute>
  <xsl:attribute name="space-before.optimum">60pt</xsl:attribute>
  <xsl:attribute name="padding-top">3pt</xsl:attribute>
  <xsl:attribute name="text-align-last">justify</xsl:attribute>
  <xsl:attribute name="margin-left">25pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Version">
<fo:block xsl:use-attribute-sets="version-text-style">
<xsl:apply-templates/><fo:leader leader-pattern="space"/><xsl:value-of select="following-sibling::Date"/>
</fo:block>
</xsl:template>


<xsl:attribute-set name="list-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="start-indent">2cm</xsl:attribute>
  <xsl:attribute name="provisional-distance-between-starts">12pt</xsl:attribute>  
  <xsl:attribute name="space-before.optimum">15pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="contained-list-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="start-indent">3cm</xsl:attribute>
  <xsl:attribute name="provisional-distance-between-starts">12pt</xsl:attribute>  
  <xsl:attribute name="space-before.optimum">5pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="BulletList">
<xsl:if test="not(parent::Bullet)">
<fo:list-block xsl:use-attribute-sets="list-style">
<xsl:for-each select="Bullet">
<fo:list-item>
<fo:list-item-label end-indent="label-end()">
<fo:block><fo:inline font-family="Symbol"><xsl:if test="not(//@id='GNUFDL')">&#x2022;</xsl:if></fo:inline></fo:block>
</fo:list-item-label>
<fo:list-item-body start-indent="body-start()">				
<fo:block><xsl:apply-templates/></fo:block>

<!-- if contains a child BulletList node -->
<xsl:if test="BulletList">					
<xsl:for-each select="BulletList">
<fo:list-block xsl:use-attribute-sets="contained-list-style">
<xsl:for-each select="Bullet">
<fo:list-item><fo:list-item-label end-indent="label-end()">
<fo:block><fo:inline font-family="Symbol">&#x2022;</fo:inline></fo:block>
</fo:list-item-label>
<fo:list-item-body start-indent="body-start()">
<fo:block><xsl:apply-templates/></fo:block>
</fo:list-item-body>
</fo:list-item>
</xsl:for-each>
</fo:list-block>	
</xsl:for-each>
</xsl:if>
</fo:list-item-body></fo:list-item></xsl:for-each></fo:list-block></xsl:if>
</xsl:template>


<xsl:attribute-set name="contained-number-list-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="start-indent">3cm</xsl:attribute>
  <xsl:attribute name="provisional-distance-between-starts">12pt</xsl:attribute>  
  <xsl:attribute name="space-before.optimum">15pt</xsl:attribute>
  <xsl:attribute name="space-after.optimum">15pt</xsl:attribute>  
</xsl:attribute-set>
<xsl:template match="NumberedList">
<fo:list-block xsl:use-attribute-sets="list-style">
<xsl:for-each select="NumberedItem">
<fo:list-item><fo:list-item-label end-indent="label-end()">
<fo:block><fo:inline font-family="Symbol"><xsl:number/>.</fo:inline></fo:block>
</fo:list-item-label>
<fo:list-item-body start-indent="body-start()">
<xsl:choose>
<!-- does not contain child (indented) Text or CodeLines -->
<xsl:when test="(count(Text)+count(CodeLine))=1">
<fo:block><xsl:apply-templates select="Text/node()"/></fo:block>
</xsl:when>

<!-- contains child (indented) Text or CodeLines -->
<xsl:otherwise>
<fo:block><xsl:apply-templates select="Text[1]/node()"/></fo:block>
<fo:list-block xsl:use-attribute-sets="contained-number-list-style">
<xsl:for-each select="child::*[position()>1]">
<fo:list-item><fo:list-item-label end-indent="label-end()"><fo:block/></fo:list-item-label>
<fo:list-item-body><fo:block><xsl:apply-templates/></fo:block></fo:list-item-body>
</fo:list-item>
</xsl:for-each>
</fo:list-block>
</xsl:otherwise>
</xsl:choose>
</fo:list-item-body>
</fo:list-item>
</xsl:for-each>
</fo:list-block>
</xsl:template>



<xsl:template match="CodeLine">
<fo:block font-size="8.0pt" font-family="Courier" color="black" text-align="left">
<xsl:choose>
<xsl:when test="parent::NumberedItem or parent::Bullet"/>
<!-- normal code lines -->
<xsl:when test="not(parent::Figure) and not(parent::th)">
<xsl:attribute name="margin-left">50pt</xsl:attribute>
<xsl:if test="not(name(preceding-sibling::*[position()=1])='CodeLine')">
<xsl:attribute name="space-before.optimum">8pt</xsl:attribute>
</xsl:if>
</xsl:when>

<!-- codeline in a hidden table -->
<xsl:when test="parent::th and ../../../../@class='hidden'">
<xsl:attribute name="margin-left">10pt</xsl:attribute>
<xsl:attribute name="space-before.optimum">8pt</xsl:attribute>
<xsl:attribute name="space-after.optimum">8pt</xsl:attribute>
</xsl:when>
<!-- normal table -->
<xsl:otherwise>
<xsl:if test="not(parent::th)">
<xsl:attribute name="space-before.optimum">3pt</xsl:attribute>
</xsl:if>
</xsl:otherwise>
</xsl:choose>

<xsl:apply-templates/>
</fo:block>

<!--
<xsl:param name="withLineNumber">n</xsl:param>
<xsl:choose>
<xsl:when test="not(parent::Figure) and not(parent::th)">
<fo:block font-size="8.0pt" font-family="Courier" color="black" text-align="left" margin-left="50pt">
<xsl:if test="not(name(preceding-sibling::*[position()=1])='CodeLine')">
<xsl:attribute name="space-before.optimum">8pt</xsl:attribute>
</xsl:if>
<xsl:apply-templates/>
</fo:block>
</xsl:when>

<xsl:when test="parent::th and ../../../../@class='hidden'">
<fo:block font-size="8.0pt" font-family="Courier" color="black" 
text-align="left" margin-left="10pt" space-before.optimum="8pt" space-after.optimum="8pt">
<xsl:apply-templates/>
</fo:block>
</xsl:when>

<xsl:otherwise>
<fo:block font-size="8.0pt" font-family="Courier" color="black" text-align="left">
<xsl:if test="not(parent::th)">
<xsl:attribute name="space-before.optimum">3pt</xsl:attribute>
</xsl:if>
<xsl:if test="$withLineNumber='y'"><xsl:number/></xsl:if>
<xsl:apply-templates/>
</fo:block>
</xsl:otherwise>
</xsl:choose>
-->
</xsl:template>


<!-- table -->
<xsl:attribute-set name="first-table-in-chapter-style">
  <xsl:attribute name="space-before.optimum">30pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Table">
<fo:table table-layout="fixed" width="100%" keep-with-previous="always">
<xsl:if test="not(preceding-sibling::*)"><fo:block space-before.optimum="25pt"/></xsl:if>
<fo:table-column column-width="proportional-column-width(1)"/>
<fo:table-body>
<!-- table title -->
<!--
<fo:table-row>-->
<!-- always keep the table title with the table -->
<!--<xsl:if test="not(normalize-space(Title/Text)='')"><xsl:attribute name="keep-with-next">always</xsl:attribute></xsl:if>				
<fo:table-cell>
<fo:block>
<xsl:if test="not(normalize-space(Title/Text)='')"><xsl:apply-templates select="Title"/></xsl:if>
</fo:block>
</fo:table-cell>
</fo:table-row>-->
<xsl:if test="not(normalize-space(Title/Text)='')">
<fo:table-row keep-with-next="always"><fo:table-cell><fo:block><xsl:apply-templates select="Title"/></fo:block></fo:table-cell></fo:table-row></xsl:if>
<!-- table content -->
<fo:table-row>
<fo:table-cell>
<fo:block>
<!-- use nested table to center-align the table -->
<fo:table table-layout="fixed" width="100%">
<fo:table-column column-width="25pt"/>
<fo:table-column column-width="60pt"/>				
<fo:table-body>
<fo:table-row>
<fo:table-cell column-number="1"/>
<fo:table-cell column-number="2">
<fo:table table-layout="fixed">
<xsl:for-each select="TableContent/tr[1]/th">
<fo:table-column>
<!-- calculate the column width based on the width in the original html file -->
<xsl:attribute name="column-width">
<xsl:value-of select="concat(number(@width) * 0.8, 'px')"/>
</xsl:attribute>
</fo:table-column>
</xsl:for-each>
<fo:table-body>
<xsl:for-each select="TableContent/tr">
<fo:table-row>
<!-- the table is not at the beginning of a chapter, otherwise, it will start from a new page, doesn't look nice -->
<xsl:if test="../../preceding-sibling::*"><xsl:attribute name="keep-with-next">always</xsl:attribute></xsl:if>
<xsl:for-each select="th">
<xsl:choose>
<!-- when the cell contains only text -->
<xsl:when test="not(../../../@class='hidden') and not(File)">
<fo:table-cell column-number="{position()}" vertical-align="top" padding="2pt" border="0.5pt" border-color="black" border-style="solid">
<xsl:if test="position()=1 and normalize-space(../../tr[1]/th[1])=''"><xsl:attribute name="text-align">right</xsl:attribute></xsl:if>
<xsl:if test="position()>1 and not(last())"><xsl:attribute name="text-align">left</xsl:attribute></xsl:if>
<xsl:if test="last()"><xsl:attribute name="text-align">justify</xsl:attribute></xsl:if>
<xsl:apply-templates/>
</fo:table-cell>
</xsl:when>
<!-- when the cell is an image --> 
<xsl:when test="not(../../../@class='hidden') and File">
<fo:table-cell column-number="{position()}" vertical-align="top" text-align="right" padding="2pt" border="0.5pt" border-color="black" border-style="solid">
<xsl:apply-templates/>
</fo:table-cell>
</xsl:when>
<!-- deal with hidden table -->
<xsl:when test="../../../@class='hidden'">
<fo:table-cell column-number="{position()}" vertical-align="top" padding="2pt">
<xsl:if test="position()=1"><xsl:attribute name="text-align">left</xsl:attribute></xsl:if>
<xsl:if test="position()>1"><xsl:attribute name="text-align">justify</xsl:attribute></xsl:if>
<xsl:apply-templates/>
</fo:table-cell></xsl:when></xsl:choose></xsl:for-each></fo:table-row></xsl:for-each></fo:table-body></fo:table></fo:table-cell>
</fo:table-row></fo:table-body></fo:table></fo:block></fo:table-cell></fo:table-row></fo:table-body></fo:table>
</xsl:template>



<!-- Figure -->
<xsl:template match="Figure">
<fo:table table-layout="fixed" width="100%">
<fo:table-column column-width="proportional-column-width(1)"/>
<fo:table-body>
<!-- figure title -->
<!-- number of current figure = total_number_of_previous_figure - total_number_of_previous_sub_figures-->
<xsl:variable name="temp_total_figs"><xsl:number count="Figure" level="any"/></xsl:variable>       
<xsl:variable name="temp_num_of_sub_figs">
  <xsl:number count="Figure[Title/SubTitle and substring(translate(@id, '_0123456789', '99999999999'), string-length(@id)-1, string-length(@id))='99']" level="any"/>
</xsl:variable>  	  	
<xsl:variable name="no"><xsl:value-of select="$temp_total_figs - $temp_num_of_sub_figs"/></xsl:variable>

<fo:table-row keep-with-next="always"><fo:table-cell><fo:block>
<xsl:apply-templates select="Title" mode="Figure"><xsl:with-param name="no" select="$no"/></xsl:apply-templates>
</fo:block></fo:table-cell></fo:table-row>

<fo:table-row><fo:table-cell>
<xsl:if test="File"><xsl:apply-templates select="File"/></xsl:if>
<xsl:if test="CodeLine">
<fo:block text-align="left">
<fo:table start-indent="3pt" table-layout="fixed" width="100%" border-spacing="3pt">
<fo:table-column column-width="proportional-column-width(1)"/>
<fo:table-column column-width="100mm"/>
<fo:table-column column-width="proportional-column-width(1)"/>
<fo:table-body>
<fo:table-row>
<fo:table-cell column-number="2">
<xsl:if test="not(@calss='withLineNumber')">
  <xsl:attribute name="border-width">0.1pt</xsl:attribute><xsl:attribute name="border-style">solid</xsl:attribute>
  <xsl:attribute name="border-color">black</xsl:attribute><xsl:attribute name="border-collapse">separate</xsl:attribute>
</xsl:if>

<xsl:choose>
<!-- display the codeline number besides each codeline using nested table -->
<xsl:when test="@class='withLineNumber'">
<fo:table start-indent="3pt" table-layout="fixed" width="100%" border-spacing="3pt">
<fo:table-column column-width="28pt"/>						  
<fo:table-column column-width="proportional-column-width(1)" border-width="0.1pt" border-style="solid" border-color="black" border-collapse="separate"/>
<fo:table-body>
<xsl:for-each select="CodeLine">
<fo:table-row>
<fo:table-cell column-number="1">
<fo:block xsl:use-attribute-sets="codeline-in-table-style"><xsl:number/></fo:block>
</fo:table-cell>
<fo:table-cell column-number="2"><xsl:apply-templates select="."/></fo:table-cell>
</fo:table-row>
</xsl:for-each>
</fo:table-body>
</fo:table>										
</xsl:when>
<xsl:otherwise><xsl:apply-templates select="CodeLine"/></xsl:otherwise>
</xsl:choose></fo:table-cell></fo:table-row></fo:table-body></fo:table></fo:block></xsl:if>
</fo:table-cell></fo:table-row></fo:table-body></fo:table>
</xsl:template>



<xsl:template match="File">
<xsl:variable name="height"><xsl:value-of select="@height"/>em</xsl:variable>
<xsl:variable name="width"><xsl:value-of select="@width"/>em</xsl:variable>
<xsl:variable name="url">
<xsl:choose>
<xsl:when test="contains(@url, 'User_Fig_17.png') or contains(@url, 'User_Fig_18')"><xsl:value-of select="concat(substring-before(@url, '.png'), '_resized.png')"/></xsl:when>
<xsl:otherwise><xsl:value-of select="@url"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<fo:block display-align="center" text-align="center" space-after.optimum="15pt" space-before.optimum="3pt">
<xsl:if test="not(parent::th)"><xsl:attribute name="margin-left">25pt</xsl:attribute></xsl:if>
<fo:external-graphic display-align="center" src="{$url}" content-height="{$height}" content-width="{$width}"/>
</fo:block>
</xsl:template>


<!-- reference in the text to a footnote -->
<xsl:template match="FootnoteRef">
<xsl:variable name="no"><xsl:value-of select="@id"/></xsl:variable>
<fo:footnote>
<fo:inline baseline-shift="super" font-size="smaller">[<xsl:value-of select="$no"/>]</fo:inline>
<fo:footnote-body>
<fo:list-block provisional-label-separation="0pt" provisional-distance-between-starts="18pt" space-after.optimum="6pt">
<fo:list-item>
<fo:list-item-label end-indent="label-end()"><fo:block>[<xsl:number count="//FootnoteRef" level="any"/>]</fo:block></fo:list-item-label>
<fo:list-item-body start-indent="body-start()"><fo:block><xsl:apply-templates select="//Footnote[@id=$no]"/></fo:block></fo:list-item-body>
</fo:list-item>
</fo:list-block>
</fo:footnote-body>
</fo:footnote>
</xsl:template>


<xsl:attribute-set name="bibitem-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">11.0pt</xsl:attribute>
  <xsl:attribute name="color">black</xsl:attribute>
  <xsl:attribute name="text-align">justify</xsl:attribute>
  <xsl:attribute name="space-before.optimum">15pt</xsl:attribute>
  <xsl:attribute name="margin-left">25pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="BibItem">
<fo:block xsl:use-attribute-sets="bibitem-text-style"><xsl:apply-templates/></fo:block>
</xsl:template>


<xsl:attribute-set name="author-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">15pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="space-before.optimum">25pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Author">
<fo:block xsl:use-attribute-sets="author-text-style"><xsl:apply-templates/></fo:block>
</xsl:template>


<xsl:attribute-set name="affiliation-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">10.0pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="space-before.optimum">25pt</xsl:attribute>
  <xsl:attribute name="space-after.optimum">125pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Affiliation">
<fo:block xsl:use-attribute-sets="affiliation-text-style"><xsl:apply-templates/></fo:block>
</xsl:template>

<xsl:attribute-set name="comment-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">10.0pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="space-before.optimum">25pt</xsl:attribute>
  <xsl:attribute name="margin-left">25pt</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Comment">
<fo:block xsl:use-attribute-sets="comment-text-style"><xsl:apply-templates/></fo:block>
</xsl:template>


<xsl:attribute-set name="heading-text-style">
  <xsl:attribute name="font-family"><xsl:value-of select="$font"/></xsl:attribute>
  <xsl:attribute name="font-size">18.0pt</xsl:attribute>
  <xsl:attribute name="text-align">right</xsl:attribute>
  <xsl:attribute name="color">gray</xsl:attribute>
</xsl:attribute-set>
<xsl:template match="Text" mode="heading"><fo:block xsl:use-attribute-sets="heading-text-style"><xsl:apply-templates/></fo:block></xsl:template>


<xsl:template match="text()"><xsl:value-of select="."/></xsl:template>
<xsl:template match="br"><fo:block/></xsl:template>
<xsl:template match="Footnote"><xsl:apply-templates/></xsl:template>
<xsl:template match="Section"><xsl:apply-templates/></xsl:template>
<xsl:template match="Content"><xsl:if test="contains(parent::Chapter/@id, 'appendix')"><fo:block><xsl:apply-templates/></fo:block></xsl:if><xsl:if test="not(contains(parent::Chapter/@id, 'appendix'))"><xsl:apply-templates/></xsl:if></xsl:template>
<xsl:template match="b"><fo:inline font-weight="bold"><xsl:apply-templates/></fo:inline></xsl:template>
<xsl:template match="i"><fo:inline font-style="italic"><xsl:apply-templates/></fo:inline></xsl:template>
<xsl:template match="u"><fo:inline text-decoration="underline" color="blue"><xsl:apply-templates/></fo:inline></xsl:template>
<xsl:template match="FileName"/>
</xsl:stylesheet>
